Question Answering in Context is a dataset for modeling, understanding, and
participating in information seeking dialog. Data instances consist of an
interactive dialog between two crowd workers: (1) a student who poses a sequence
of freeform questions to learn as much as possible about a hidden Wikipedia
text, and (2) a teacher who answers the questions by providing short excerpts
(spans) from the text. QuAC introduces challenges not found in existing machine
comprehension datasets: its questions are often more open-ended, unanswerable,
or only meaningful within the dialog context.
